#[unsafe(no_mangle)]pub unsafe extern "C" fn islet_attest(
user_data: *const c_uchar,
user_data_len: c_int,
report_out: *mut c_uchar,
report_out_len: *mut c_int,
) -> islet_status_tExpand description
Get an attestation report(token).
Note
This API currently returns hard-coded report to simulate attest operation.
In future, this will be finalized to support reports signed by RMM.
User data could be used as nonce to prevent reply attack.